==> haskell-test-lib-0.3-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-lib
version:              0.3
visibility:           public
id:                   test-lib-0.3-HksheUHvxPBIcMEEdyoVHE
key:                  test-lib-0.3-HksheUHvxPBIcMEEdyoVHE
license:              ISC
maintainer:           iavor.diatchki@gmail.com
author:               Iavor Diatchki
synopsis:             A library to make a quick test-runner script.
description:
    This library makes it easy to define an executable,
    which can find and run a bunch of tests for a binary.

category:             Testing
abi:                  979c22b923a3d325bf678668b75bbde8
exposed:              True
exposed-modules:      TestLib
hidden-modules:       Paths_test_lib
import-dirs:          /usr/lib/ghc-9.0.1/site-local/test-lib-0.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/test-lib-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/test-lib-0.3
hs-libraries:         HStest-lib-0.3-HksheUHvxPBIcMEEdyoVHE
depends:
    HUnit-1.6.2.0-2lDDmQCEetY9OrwZ2lDZMS base-4.15.0.0
    containers-0.6.4.1 directory-1.3.6.1 filepath-1.4.2.1
    process-1.6.11.0 simple-get-opt-0.4-4dXPgqEN9yMLy0T73tsPlq
    test-framework-0.8.2.0-InIxjlaLDti8DjYJMiiCBZ
    test-framework-hunit-0.3.0.2-2Q2WNPaFJRG886pHeBEAlm

haddock-interfaces:   /usr/share/doc/haskell-test-lib/html/test-lib.haddock
haddock-html:         /usr/share/doc/haskell-test-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-lib-0.3-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-lib
version:              0.3
visibility:           public
id:                   test-lib-0.3-CQeuAnkCmyU3eHNIQ0BwBF
key:                  test-lib-0.3-CQeuAnkCmyU3eHNIQ0BwBF
license:              ISC
maintainer:           iavor.diatchki@gmail.com
author:               Iavor Diatchki
synopsis:             A library to make a quick test-runner script.
description:
    This library makes it easy to define an executable,
    which can find and run a bunch of tests for a binary.

category:             Testing
abi:                  e981de75622e7a88050d16072b5441f3
exposed:              True
exposed-modules:      TestLib
hidden-modules:       Paths_test_lib
import-dirs:          /usr/lib/ghc-9.0.1/site-local/test-lib-0.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/test-lib-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/test-lib-0.3
hs-libraries:         HStest-lib-0.3-CQeuAnkCmyU3eHNIQ0BwBF
depends:
    HUnit-1.6.2.0-2lDDmQCEetY9OrwZ2lDZMS base-4.15.0.0
    containers-0.6.4.1 directory-1.3.6.1 filepath-1.4.2.1
    process-1.6.11.0 simple-get-opt-0.4-4dXPgqEN9yMLy0T73tsPlq
    test-framework-0.8.2.0-BDQIDvoiNqdFYQJQ5b4Tt
    test-framework-hunit-0.3.0.2-8y1X70d92zOApmTv65xjLS

haddock-interfaces:   /usr/share/doc/haskell-test-lib/html/test-lib.haddock
haddock-html:         /usr/share/doc/haskell-test-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
